from enum import IntEnum

class ItemType(IntEnum):
    Empty = 0,

    PlaceHolder = 1,

    SkyCompass = 11,
    LinkedCompass = 12,
    PuzzlePiece = 16,
    # CreatureBattle = 19,  # ==> remove
    Animal = 17,
    Beast = 18,
    Monster = 19,
    HermesStatue = 21,
    MuseStatue = 22,

    # ====== Hermestatue ======
    # ====== MuseStatue ======

    # ====== Flowers ======
    SmallDogViolet = 101,
    RedRose = 102,
    SingleRedRose = 103,
    WildGarlic = 104,
    WoodAnemoneBranch = 105,
    YellowPrimrose = 106,
    # ====== ConiferTree ======
    MountainPine = 201,
    Pine = 202,
    MacedonianPine = 203,
    GreenScotsPine = 204,
    YoungScotsPine = 205,
    # ====== BroadLeafTrees ======
    Beech = 301,
    LittleBranch = 302,
    SmallAppleTree = 303,
    YoungBeech = 304,
    # ====== Bushes ======
    CommonBoxBush = 401,
    CommonBoxSphereBush = 402,
    PrivetBush = 403,
    WildPrivetBush = 404,
    # ====== Grass ======
    CommonButterbu = 501,
    CommonCouchGrass = 502,
    SkunkCabbage = 503,
    WildGarlicGrass = 504,
    WoodMelick = 505,
    # ====== Mushrooms ======
    Champignon = 601,
    FlyAmanita = 602,
    Lactarius = 603,
    PholiotaMicrospora = 604,
    SulphurTuft = 605,
    TallFlyAmanita = 606,
    # ====== Stones ======
    DirtMossedStone = 701,
    MossedStone = 702,
    WhiteMossedStone = 703,
    WhiteSharpStone = 704,
    WhiteStone = 705,

    MidDirtStone = 721,
    # ====== Houses ======
    AdorableRedWoodenHouseWithTree = 801,
    ThatchedHut = 802,

    # def insert_enum(conn):
    #     create_enum_type(E.ItemType, ItemType, conn)



from enum import IntEnum
from volworld_common.api.enum.common_error_code import CommonErrorCode


class ErrorCode(IntEnum):
    NoError = CommonErrorCode.NoError.value

    NoNeedToUpdate = 311

    Forbidden = 403
    TargetObjectNotFound = 404

    NotEnoughResource = 512

    RequestTooManyImages = 603

    CanNotUndo = 701

    # ====== 1000 auth ======
    UserNameExisting = 1001
    WrongUserNameFormat = 1002
    TooShortPassword = 1003
    NotLogin = 1004
    WrongPassword = 1011
    CanNotUpdateSystemUsers = 1021
    NoPermission = 1022
    NotTestUser = 1023
    NotRootUser = 1024

    # ===== 1101-1399 Adventurer Common =====
    # ===== 1401-1599 Designer Common =====
    NotDesignAuthor = 1403
    # ===== 1601-1799 Learner Common =====

    # ====== 4000 (extend HTML 4xx) ======
    VersionMismatch = 4010
    EventMismatch = 4011

    # ====== 4100 user ======
    UserNotFound = 4100
    UserIdExisting = 4101

    # ====== 4200 SA ======
    SaNotFound = 4200

    # ====== 4500 Puzzle ======
    PuzzleNotFound = 4500
    PuzzleChallengeNotFound = 4501
    PuzzleChallengeAlreadyFinished = 4502
    PuzzleDesignNotFound = 4503
    PuzzleContextNotFound = 4530
    PuzzleIsPublished = 4580
    PuzzleIsArchived = 4581
    PuzzleIsNotPublished = 4582

    # ====== 4600 Site ======
    SiteNotFound = 4600
    SiteChallengeNotFound = 4601
    SiteChallengeAlreadyConquered = 4602
    NotInSiteChallenge = 4603
    AlreadyInSiteChallenge = 4605
    SiteContextNotFound = 4630
    SiteIsPublished = 4680
    SiteIsArchived = 4681
    SiteIsNotPublished = 4682

    # ====== 4700 Lane ======
    LaneNotFound = 4700
    LaneChallengeNotFound = 4701
    LaneChallengeAlreadyConquered = 4702
    NotInLaneChallenge = 4703
    AlreadyInLaneChallenge = 4705
    LaneContextNotFound = 4730
    ChallengeLaneNotFound = 4760
    LaneIsPublished = 4780
    LaneIsArchived = 4781
    LaneIsNotPublished = 4782

    # ====== 5000 Server Error ======



from typing import Final

class NullUser:
    Id: Final[int] = 0
    Uuid: Final[str] = 'ae5b3e33-8176-45f0-bf91-5ddaef367637'
    Name: Final = 'null'

class SystemUser:
    Id: Final[int] = 1
    Uuid: Final[str] = '35be7c40-5a98-457c-bccb-d2dbd8da1cb8'
    Name: Final = 'sys'

class RootUser:
    Id: Final[int] = 9
    Uuid: Final[str] = '26101fe2-f8e8-4ab9-8524-d3caaa01bac0'
    Name: Final = 'root'
